@@ -61,7 +61,7 @@ mesaplot.Qval <-
 
         locy <- no.qvector-(L-which(order(fullPVAF[,y],decreasing = F)==locy0))
         ordered.PVAF.j <- sort(fullPVAF[,y],decreasing = FALSE)
-        plot(ordered.PVAF.j[(L-no.qvector+1):L],xaxt="n",type="o",ylab = "PVAF",xlab="q-vectors",
+        graphics::plot(ordered.PVAF.j[(L-no.qvector+1):L],xaxt="n",type="o",ylab = "PVAF",xlab="q-vectors",
              main = paste("Mesa Plot for Item",y),ylim = c(0,1),...)
         axis(1,at=c(1:no.qvector),labels = names(ordered.PVAF.j[(L-no.qvector+1):L]))
         if (locy>0){
@@ -86,16 +86,16 @@ mesaplot.Qval <-
       for(j in item){
         bestloc <- match(bestPVAF[,j],fullPVAF[,j])
         if (auto.ylim) ylim = c(max(0,round(min(bestPVAF[,j])-0.1,1)),1) else ylim=c(0,1)
-        plot(bestPVAF[,j],xaxt="n",type="o",ylab = "PVAF",xlab="q-vectors",
+        graphics::plot(bestPVAF[,j],xaxt="n",type="o",ylab = "PVAF",xlab="q-vectors",
              main = paste("Mesa Plot for Item",j),ylim = ylim,...)
-        axis(1,at=c(1:nrow(bestPVAF)),labels = label.bestPVAF[bestloc])
+        graphics::axis(1,at=c(1:nrow(bestPVAF)),labels = label.bestPVAF[bestloc])
         if (!is.null(eps)&&eps>0&&eps<1) abline(h=eps,lty=3);text(1.5,eps+0.03,paste("eps =",eps))
         yloc <- bestPVAF[,j]-diff(ylim)/15
         yloc[yloc<=ylim[1]] <- yloc[yloc<=ylim[1]] + 2 * diff(ylim)/15
-        if (data.label) text(c(1:nrow(bestPVAF)),yloc,bestPVAF[,j])
+        if (data.label) graphics::text(c(1:nrow(bestPVAF)),yloc,bestPVAF[,j])
         locy0 <- which(apply(patt,1,function(x){
           all(x==Q[j,])}))
-        if(locy0%in%bestloc) points(which(bestloc==locy0),fullPVAF[locy0,j],col="red",pch=19)
+        if(locy0%in%bestloc) graphics::points(which(bestloc==locy0),fullPVAF[locy0,j],col="red",pch=19)
         if (original.q.label) text(K-1,ylim[1]+diff(ylim)/6,paste("original q-vector:\n",names(fullPVAF[,j])[locy0]))
       }
     }
